@@ -7,9 +7,10 @@ import typing as t
 from datetime import datetime
 
 from click import confirm
-from kiraak.mapping import Mapping
+from rich import print_json
 
 from kiraak.config import API, session
+from kiraak.order import Order
 
 logger = logging.getLogger(__name__)
 
@@ -77,34 +78,41 @@ def get_customer(flat) -> dict:
             (
                 x
                 for x in customers["viewAllCustomers"]
-                if x["customerCommunityInfo"]["customerHouseNo"] == flat
+                if x["customerCommunityInfo"]["customerHouseNo"].strip() == flat
             )
         )
     except StopIteration:
-        logger.error(f"User @ {flat} not found!")
-        sys.exit(1)
+        logger.error(f"User @ {flat} not found, skipping!")
 
 
 @authorized
-def get_current_order(customer):
+def get_current_order(customer_id):
     """TODO: Get the current order of a customer"""
-    orders = session.get(API.ACTIVE_ORDERS.format(id=customer[id])).json()
+    orders = session.get(API.CUSTOMER_ACTIVE_ORDER.format(id=customer_id)).json()
+    return orders
 
 
 @authorized
-def add_order(order: t.Dict[str, str], mapping: Mapping, price_id) -> None:
+def merge_and_update(curr_order, new_order, price_id, order_obj):
+    logger.error("WARNING: NOTHING HAPPEND, please merge the orders yourself, TODO")
+
+
+@authorized
+def add_order(order_data: t.Dict[str, str], price_id, orderobj: Order) -> None:
     """Adds the given order using the kiraak API"""
-    customer = get_customer(order["flat"])
+    customer = get_customer(order_data["flat"])
+    if not customer:
+        return
     data = {
         "orderType": "regular",
         "priceId": price_id,
         "customerId": customer["_id"],
         "orderSource": "whatsApp",
         "orderNote": "",
-        "orderBillAmount": order["total"],
+        "orderBillAmount": order_data["total"],
         "cartList": [],
     }
-    for prod in order["products"]:
+    for prod in order_data["products"]:
         data["cartList"].append(
             {
                 "productId": prod["cat"].product_id,
@@ -113,22 +121,31 @@ def add_order(order: t.Dict[str, str], mapping: Mapping, price_id) -> None:
                 "productBaseQuantity": prod["cat"].quantity,
             }
         )
+    if (curr_order := get_current_order(customer['_id']))['orderAvailable']:
+        if confirm('Order already exists, add new items to current order?'):
+            logger.info(f"Merging orders for {orderobj.name} @ {orderobj.flat}!")
+            merge_and_update(curr_order, order_data, price_id, orderobj)
+        else:
+            logger.error("Order not updated, skipping!")
+        return
+
     res = session.post(API.ADD_ORDER, json=data).json()
-    if res["message"] == (
-        "Failed to add order: there is an active order, "
-        "please process the active order to place a new order"
-    ):
-        logger.error(f"Failed to add order: {res['message']}")
-        sys.exit(1)
-        # TODO: Complete
-        if confirm(
-            f"An order already exists for {order['name']} @ {order['flat']}"
-            ", do you want to replace it?"
-        ):
-            current = get_current_order(customer)
-            res = session.put(API.UPDATE_ORDER.format(id=current[""]), json=data).json()
-    elif res["message"] != "order created successfully":
+    # if res["message"] == (
+    #     "Failed to add order: there is an active order, "
+    #     "please process the active order to place a new order"
+    # ):
+    #     logger.error(f"Failed to add order: {res['message']}")
+    #     sys.exit(1)
+    #     # TODO: Complete
+    #     if confirm(
+    #         f"An order already exists for {order['name']} @ {order['flat']}"
+    #         ", do you want to replace it?"
+    #     ):
+    #         current = get_current_order(customer)
+    #         res = session.put(API.UPDATE_ORDER.format(id=current[""]), json=data).json()
+    if res["message"] != "order created successfully":
         logger.error(f"Failed to add order: {res['message']}")
         sys.exit(1)
     else:
+        orderobj.added = True
         logger.info("Added order!")
