@@ -1,20 +1,32 @@
 """Main CLI application"""
 import json
+import sys
 
 import click
 
+from kiraak.config import API, Auth
 from kiraak.main import main
-from kiraak.config import Config, API
 
 
 @click.command()
-@click.argument("json_file", type=click.Path(exists=True, dir_okay=False))
-@click.option("--clear", is_flag=True)
-def cli(json_file: str, clear) -> None:
+@click.argument("json_file", type=click.Path(exists=True, dir_okay=False), required=False)
+@click.option("-c", "--clear", is_flag=True)
+@click.option("-g", "--get-catalog", is_flag=True)
+def cli(json_file: str, clear, get_catalog) -> None:
     """Initiates cli"""
     if clear:  # Clear cached login data
-        Config.CONF_FILE.unlink()
+        Auth.CONF_FILE.unlink()
         API.TOKEN_FILE.unlink()
+        sys.exit()
+
+    if get_catalog:
+        from kiraak.get_catalog import download_catalog
+        download_catalog()
+        sys.exit()
+
+    if not json_file:
+        click.echo("No json file provided")
+        raise click.Abort()
 
     if not json_file.endswith(".json"):
         click.echo("File must be a JSON file (.json)!")
