@@ -1,27 +1,26 @@
 """Processing of json file and adding orders"""
 import json
 import logging
+from math import prod
 
 from rich.table import Table
 
 from kiraak import console
 from kiraak.add_orders import add_orders
 from kiraak.api import get_catalog, login
-from kiraak.config import Config
 from kiraak.catalog import Catalog
+from kiraak.config import Auth
 from kiraak.order import OrderList
 
 logger = logging.getLogger(__name__)
 
 
-# TODO: Finish this OOP approach for the program
-
 def main(file: str) -> None:
     """Process files, adds orders"""
 
     # Login
-    logger.info(f"Logging in as {Config.MOBILE}")
-    partner_info = login(Config.MOBILE, Config.PASSWORD)
+    logger.info(f"Logging in as {Auth.MOBILE}")
+    partner_info = login(Auth.MOBILE, Auth.PASSWORD)
     logger.info(
         f"Logged in as {partner_info['partnerName']} @ {partner_info['partnerBrand']}"
     )
@@ -31,6 +30,7 @@ def main(file: str) -> None:
     catalog = Catalog(get_catalog())
     logger.info(f"Recieved catalog (id {catalog.id})")
     tbl = Table(
+        "Product ID",
         "Product Name",
         "Description",
         "Price",
@@ -39,6 +39,7 @@ def main(file: str) -> None:
     )
     for product in catalog:
         tbl.add_row(
+            product.product_id,
             product.name,
             product.desc,
             f"₹ {product.price}",
@@ -56,5 +57,5 @@ def main(file: str) -> None:
     logger.info(f"Adding {len(orders)} orders...")
     add_orders(orders, catalog)
     logger.info(
-        f"Added {len(orders)} orders!\n[bold]All done![/]", extra={"markup": True}
+        f"Added {len(list(filter(lambda x: x.added, orders)))} orders!\n[bold]All done![/]", extra={"markup": True}
     )
